#
# spec file for package ibus-typing-booster
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-typing-booster
Version:        2.26.11
Release:        1.1
Summary:        An input completion utility
License:        GPL-3.0-or-later
Group:          System/X11/Utilities
URL:            https://mike-fabian.github.io/ibus-typing-booster/
Source0:        https://github.com/mike-fabian/ibus-typing-booster/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://releases.pagure.org/inscript2/inscript2-20210820.tar.gz
BuildRequires:  AppStream
BuildRequires:  appstream-glib
BuildRequires:  dbus-1-x11
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  glib2
BuildRequires:  glibc-locale
BuildRequires:  gtk3
BuildRequires:  ibus-devel
BuildRequires:  m17n-db
# for the unit tests
BuildRequires:  m17n-lib
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
# Because of “from packing import version”:
BuildRequires:  python3-packaging
BuildRequires:  python3-pyenchant
# To avoid requiring Python >= 3.8
BuildRequires:  python3-typing_extensions
BuildRequires:  update-desktop-files
Requires:       dbus-1-python3
# Workaround bug with python3-enchant: https://bugzilla.opensuse.org/show_bug.cgi?id=1141993
Requires:       enchant-1-backend
#
Requires:       ibus >= 1.5.3
Requires:       m17n-lib
Requires:       python3 >= 3.6
Requires:       python3-distro
# Because of “from packing import version”:
Requires:       python3-packaging
Requires:       python3-pyenchant
Requires:       python3-pyxdg
Recommends:     gdouros-symbola-fonts
# Recommend reasonably good fonts which have most of the emoji:
Recommends:     noto-coloremoji-fonts
# For speech recognition:
Recommends:     python3-PyAudio
# To make the setup tool look nicer and the search for dictionaries and imes better:
Recommends:     python3-langtable
# Better regexpressions (optional):
Recommends:     python3-regex
# To play a sound on error:
Recommends:     python3-simpleaudio
%if 0%{?sle_version} >= 120200
BuildRequires:  python3-pyxdg
%endif
%if 0%{?suse_version} == 1320
BuildRequires:  myspell-de
BuildRequires:  myspell-en
BuildRequires:  myspell-es
BuildRequires:  myspell-it_IT
%else
BuildRequires:  myspell-de
BuildRequires:  myspell-de_DE
BuildRequires:  myspell-en
BuildRequires:  myspell-en_US
BuildRequires:  myspell-es
BuildRequires:  myspell-es_ES
BuildRequires:  myspell-fr_FR
BuildRequires:  myspell-it_IT
%endif

%description
Ibus-typing-booster is a context sensitive completion
input method to speedup typing.

%prep
%setup -q
%if 0%{?suse_version} < 1550
##extract inscript2 maps
tar xzf %{SOURCE1}
%endif

%build
export PYTHON=%{_bindir}/python3
%configure --disable-static --libexecdir=%{_ibus_libexecdir}
%make_build

%install
export PYTHON=%{_bindir}/python3
make install DESTDIR=%{buildroot} NO_INDEX=true
gzip -n --force --best %{buildroot}/%{_datadir}/%{name}/data/*.{txt,json} \
    %{buildroot}/%{_datadir}/%{name}/data/annotations/*.xml \
    %{buildroot}/%{_datadir}/%{name}/data/annotationsDerived/*.xml

%if 0%{?suse_version} < 1550
#install inscript2 keymaps
test -d %{buildroot}%{_datadir}/m17n/icons || mkdir -p %{buildroot}%{_datadir}/m17n/icons
cp -p inscript2/IM/* %{buildroot}%{_datadir}/m17n/
cp -p inscript2/icons/* %{buildroot}%{_datadir}/m17n/icons
%endif

%suse_update_desktop_file -i -u emoji-picker GTK Utility

%fdupes %{buildroot}/%{_prefix}

%find_lang %{name}

%check
export LC_ALL=en_US.UTF-8
export M17NDIR=%{buildroot}%{_datadir}/m17n/
%if 0%{?suse_version} > 1520
#AS_VALIDATE_NONET=1 appstreamcli validate --pedantic --no-net %{buildroot}/%{_datadir}/metainfo/*.appdata.xml
%endif
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/ibus-setup-typing-booster.desktop
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/emoji-picker.desktop
pushd engine
    # run doctests
    # hunspell_suggest.py test currently doesn't work on SuSE because
    # the en_US dictionary changed apparently:
    # python3 hunspell_suggest.py -v
    if [ -e /usr/share/m17n/si-wijesekara.mim ] ; then
        python3 m17n_translit.py -v
    else
        echo "/usr/share/m17n/si-wijesekara.mim does not exist, m17n-db probably < 1.8.6, skipping doctest of m17n_translit.py"
    fi
    python3 itb_emoji.py -v
    python3 itb_util.py -v
popd
mkdir -p /tmp/glib-2.0/schemas/
cp org.freedesktop.ibus.engine.typing-booster.gschema.xml \
   /tmp/glib-2.0/schemas/org.freedesktop.ibus.engine.typing-booster.gschema.xml
glib-compile-schemas /tmp/glib-2.0/schemas #&>/dev/null || :
export XDG_DATA_DIRS=/tmp:%{_datadir} # /usr/share is needed to make enchant2 work!
eval $(dbus-launch --sh-syntax)
dconf dump /
dconf write /org/freedesktop/ibus/engine/typing-booster/offtherecord false
dconf write /org/freedesktop/ibus/engine/typing-booster/usedigitsasselectkeys true
dconf write /org/freedesktop/ibus/engine/typing-booster/addspaceoncommit true
dconf write /org/freedesktop/ibus/engine/typing-booster/tabenable false
dconf write /org/freedesktop/ibus/engine/typing-booster/inputmethod "'NoIME'"
dconf write /org/freedesktop/ibus/engine/typing-booster/rememberlastusedpreeditime true
dconf write /org/freedesktop/ibus/engine/typing-booster/mincharcomplete 1
dconf write /org/freedesktop/ibus/engine/typing-booster/dictionary "'en_US'"
dconf write /org/freedesktop/ibus/engine/typing-booster/emojipredictions true
dconf write /org/freedesktop/ibus/engine/typing-booster/autocommitcharacters "''"
dconf write /org/freedesktop/ibus/engine/typing-booster/pagesize 6
dconf write /org/freedesktop/ibus/engine/typing-booster/shownumberofcandidates true
dconf write /org/freedesktop/ibus/engine/typing-booster/showstatusinfoinaux true
dconf write /org/freedesktop/ibus/engine/typing-booster/inlinecompletion false
dconf write /org/freedesktop/ibus/engine/typing-booster/keybindings "{'next_input_method': <['Control+Down', 'Control+KP_Down']>, 'previous_input_method': <['Control+Up', 'Control+KP_Up']>, 'lookup_related': <['Mod5+F12']>, 'enable_lookup': <['Tab', 'ISO_Left_Tab', 'KP_Divide']>, 'select_next_candidate': <['Tab', 'ISO_Left_Tab', 'Down', 'KP_Down']>, 'lookup_table_page_down': <['Page_Down', 'KP_Page_Down', 'KP_Next']>, 'toggle_emoji_prediction': <['Mod5+F6']>, 'lookup_table_page_up': <['Page_Up', 'KP_Page_Up', 'KP_Prior']>, 'toggle_off_the_record': <['Mod5+F9']>, 'cancel': <['Escape']>, 'setup': <['Mod5+F10']>, 'select_previous_candidate': <['Shift+Tab', 'Shift+ISO_Left_Tab', 'Up', 'KP_Up']>}"
dconf dump /
# A window manager and and ibus-daemon are needed to run the GUI
# test tests/test_gtk.py, for example i3 can be used.
#
# To debug what is going on if there is a problem with the GUI test
# add BuildRequires: x11vnc and start a vnc server:
#
#     x11vnc -display $DISPLAY -unixsock /tmp/mysock -bg -nopw -listen localhost -xkb
#
# Then one can view what is going on outside of the chroot with vncviewer:
#
#     vncviewer /var/lib/mock/fedora-32-x86_64/root/tmp/mysock
#
# The GUI test will be skipped if XDG_SESSION_TYPE is not x11 or wayland.
#
#ibus-daemon -drx
#touch /tmp/i3config
#i3 -c /tmp/i3config &
#export XDG_SESSION_TYPE=x11

make check && rc=0 || rc=1
cat tests/*.log
if [ $rc != 0 ] ; then
    exit $rc
fi

%post
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%postun
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%files -f %{name}.lang
%license COPYING
%doc AUTHORS README README.html README.md
%{_bindir}/emoji-picker
%{_datadir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/ibus/component/typing-booster.xml
%{_datadir}/icons/hicolor/16x16/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/22x22/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/32x32/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/48x48/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/64x64/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/128x128/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/256x256/apps/ibus-typing-booster.png
%{_datadir}/icons/hicolor/scalable/apps/ibus-typing-booster.svg
%{_ibus_libexecdir}/ibus-engine-typing-booster
%{_ibus_libexecdir}/ibus-setup-typing-booster
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/org.freedesktop.ibus.engine.typing-booster.gschema.xml
%if 0%{?suse_version} < 1550
%dir %{_datadir}/m17n
%{_datadir}/m17n/*.mim
%dir %{_datadir}/m17n/icons
%{_datadir}/m17n/icons/*.png
%endif

%changelog
* Sat Nov  9 2024 maiku.fabian@gmail.com
- Update to 2.26.11
- Improve detection of Wayland session
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/561)
- Support non-ASCII input for m17n-db input methods
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/537)
- Improve “class KeyEvent”: Prepend 'S-' to msymbol
  when Shift is pressed and is is a space or not printable
- Show also the languages supported by a font in emoji-picker
  (only when -d or --debug is used)
- Fix build on Tumbleweed, in the check section of the spec file
  use `export XDG_DATA_DIRS=/tmp:%%{_datadir}` instead of just
  `export XDG_DATA_DIRS=/tmp`, otherwise enchant2 fails.
- Stop using xvfb-run for make check
* Mon Nov  4 2024 maiku.fabian@gmail.com
- Update to 2.26.8
- Get more information about the Pango rendering support for an emoji
  and use fallback in emoji-picker only when necessary
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/508)
- Also make it possible to show font file names, font versions,
  and emoji related OpenType tables of the fonts used
  (shown only in debug mode, i.e. when "emoji-picker --debug" is used,
  when not in debug mode show only the font family name)
- In do_reset() skip clearing input only when the surrounding
  text **up to the cursor** ends with the current preedit
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/529)
- Translation update from Weblate (kab 75.9%%)
* Mon Oct 28 2024 maiku.fabian@gmail.com
- Update to 2.26.6
- Simplify itb_pango.py: don’t use ctypes, use `from gi.repository import Pango` instead
- Get more information about the Pango rendering support for an emoji and use fallback
  in emoji-picker only when necessary
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/508)
- Also make it possible to show font file names, font versions,
  and emoji related OpenType tables of the fonts used
  (shown only in debug mode, i.e. when "emoji-picker --debug"
  is used, when not in debug mode show only the font family name)
- In do_reset() skip clearing input only when the surrounding text
  * *up to the cursor** ends with the current preedit
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/529)
- Translation update from Weblate (kab 75.9%%)
* Wed Oct 23 2024 maiku.fabian@gmail.com
- Update to 2.26.0
- Introduce a delay time before candidates are updated and displayed
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/530)
- emoji-picker: Show Emoji properties, Unicode category, and Unicode block always,
  not only when --debug is used. As they are now shown always, make their labels translatable.
- Translation update from Weblate (de 100%%, fr 100%%, ja 99.5%%, ka 100%%, sv 100%%, tr 100%%, uk 100%%)
* Sat Oct 19 2024 maiku.fabian@gmail.com
- Update to 2.25.19
- Translation update from Weblate (el 5.3%%, kab 34.8%%, sv 100%%)
* Wed Oct  9 2024 maiku.fabian@gmail.com
- Update to 2.25.18
- Make sure all emoji, even those which are sequences,
  get a Unicode version and not only an Emoji version
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/542)
- Translation update from Weblate (ka 100%%, pl 99.5%%, tr 100%%)
* Tue Oct  8 2024 maiku.fabian@gmail.com
- Update to 2.25.17
- Get correct Unicode version from DerivedAge.txt and also
  display both Unicode version and Emoji version in emoji-picker
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/538)
- Translation update from Weblate (de 100%%, fr 100%%, ja 100%%)
* Wed Sep 11 2024 maiku.fabian@gmail.com
- Update to 2.25.16
- When committing, normalize to NFC **and** recompose the composition exclusions
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/531)
- Update the emoji data files to the to version from the final Unicode 16.0.0 release 2024-09-10
- Update UnicodeData.txt to the Unicode 16.0.0 release 2024-09-10
- Update emoji annotations from CLDR
- Translation update from Weblate (New: el 4.9%%)
* Sun Aug 25 2024 maiku.fabian@gmail.com
- Update to 2.25.15
- Also catch ValueError exception when trying to import nltk
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/527)
- Translation update from Weblate (ru 25.1%%)
- Update emoji annotations from CLDR
* Tue Jul 23 2024 maiku.fabian@gmail.com
- Update to 2.25.14
- 'S- ' (Shift-space) should not trigger a commit if it has a transliteration
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/524)
- Update emoji annotations from CLDR
* Thu Jul 18 2024 maiku.fabian@gmail.com
- Update to 2.25.13
- Name of Sinhala input method changed in m17n-db-1.8.6: si-wijesekera ➡️ si-wijesekara
- Translation update from Weblate (new: ru 12.3%%, uk 100%%)
* Tue Jul  9 2024 maiku.fabian@gmail.com
- Update to 2.25.12
- Correct calculation of caret when a key which triggered a commit *increases* the length of the transliteration
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/519)
- Do the retransliteration of the input_phrase currently only when the cursor is at the end of the typed string
* Wed Jun 26 2024 maiku.fabian@gmail.com
- Update to 2.25.11
- Yet another fix to make it possible again to use keys with Unicode keysyms
  in keybindings and make it work with all known versions of ibus
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/497)
* Tue Jun 25 2024 maiku.fabian@gmail.com
- Update to 2.25.10
- Use NFC when doing the cursor correction after committing a preedit using space
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/515)
- Fix for ibus-1.5.30: Make it possible again to use keys with Unicode keysyms in keybindings
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/497)
* Tue Jun 18 2024 maiku.fabian@gmail.com
- Update to 2.25.9
- Translation update from Weblate (cs 100%%)
- Update emoji annotations from CLDR
- Drop Python < 3.6 support
- Fix test_0_gtk.py: typing booster now avoids clearing the input in do_reset() when the preedit is empty
* Mon May 27 2024 maiku.fabian@gmail.com
- Update to 2.25.8
- Support compose sequences containing ASCII keys written as <U00XX> code points
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/510)
- Update emoji annotations from CLDR
- Translation update from Weblate (pt 91.3%%)
* Mon Apr 15 2024 maiku.fabian@gmail.com
- Update to 2.25.7
- Don’t use forward_key_event() on Gnome Wayland if the key might be a keyboard shortcut using a modifier
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/507)
* Wed Apr 10 2024 maiku.fabian@gmail.com
- Update to 2.25.6
- If Shift+something is pressed and then released, do not swallow the release of the Shift key
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/504)
- Decrease grid_row_spacing from 5 to 1 pixels to make the setup tool still fit on a 1024x768 pixel screen
* Thu Apr  4 2024 maiku.fabian@gmail.com
- Update to 2.25.4
- Pass key which triggered cancel command to application
  if self._min_char_complete == 0 and there are no candidates
  (Resolves:  https://github.com/mike-fabian/ibus-typing-booster/issues/505)
- Update emoji annotations from CLDR
- Translation update from Weblate (ka 100%%)
* Sat Feb 24 2024 maiku.fabian@gmail.com
- Update to 2.25.3
- Add a feature to insert or remove RLM or LRM markers to
  change the direction of a line of bidi text
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/500)
* Tue Feb 13 2024 maiku.fabian@gmail.com
- Update to 2.25.1
- Make it possible to use keys with Unicode keysyms in keybindings
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/497)
- Add hack to make space handling for punctuation work for kate and kwrite
  (https://github.com/mike-fabian/ibus-typing-booster/issues/496)
- Translation update from Weblate (pl 99.5%%)
* Mon Feb  5 2024 maiku.fabian@gmail.com
- Update to 2.25.0
- Add new combobox option “Record mode”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/470)
- Improve handling of “:” for fr_CA and add fr_CH to use the same rules as fr_FR
  (Related: https://github.com/mike-fabian/ibus-typing-booster/issues/480)
- Translation update from Weblate (bn 100%%, de 100%%, fr 100%%, ja 99%%, ka 100%%, sv 100%%, tr 100%%)
* Sat Jan 27 2024 maiku.fabian@gmail.com
- Update to 2.24.12
- Improve handling of punctuation marks when writing (French) French
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/480)
* Sat Jan 20 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Sat Jan  6 2024 maiku.fabian@gmail.com
- Update to 2.24.11
- Really clear the preedit when it is empty, don’t just hide it
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/476)
  Just hiding a non-empty preedit is not enough because of
  IBus.PreeditFocusMode.COMMIT a non-empty preedit is still
  committed on focus out, even when it is hidden.
* Fri Dec 29 2023 maiku.fabian@gmail.com
- Update to 2.24.9
- Update the preedit to empty right after deleting surrounding text when reopening a preedit
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/474)
- Improve do_reset()
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/473)
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/474)
- Fix _record_in_database_and_push_context()
- Avoid updating the preedit to empty or  hiding it if the preedit is already hidden or empty
- Do not pass through a key release event if the corresponding key press event was handled
- Remove two probably redundant calls to get_surrounding_text()
- Hide and clear lookup table and aux in _update_ui_empty_input_try_completion() if no candidates are found
- Make self._ibus_event_sleep_seconds settable via gsettings
- Avoid more duplicate calls of _update_preedit()
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/473)
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/474)
- Fix disappearing first characters or words in the web clients of WhatsApp and Telegram used in Firefox
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/473)
- Update emoji annotations from CLDR
* Mon Dec 18 2023 maiku.fabian@gmail.com
- Update to 2.24.7
- Hide and clear lookup table and aux in _update_ui_empty_input_try_completion() if no candidates are found
- Make self._ibus_event_sleep_seconds settable via gsettings
- Avoid more duplicate calls of _update_preedit()
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/474)
- Fix disappearing first characters or words in the web clients of WhatsApp and Telegram used in Firefox
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/473)
- Update emoji annotations from CLDR
* Tue Dec  5 2023 maiku.fabian@gmail.com
- Update to 2.24.5
- Fix first character disappearing when compose was involved in WhatsApp and Telegram
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/471
- Update emoji annotations from CLDR
* Wed Oct 18 2023 maiku.fabian@gmail.com
- Update to 2.24.4
- Fix typos which prevented autosettings from working when the attempting
  to autoset “avoidforwardkeyevent” or “addspaceoncommit”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/469)
* Mon Oct 16 2023 maiku.fabian@gmail.com
- Update to 2.24.3
- Adapt compose test cases to newest compose table
- Parse compose sequence “<Multi_key> <slash> <slash> : "\\" backslash # REVERSE SOLIDUS”
  correctly (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/467)
- Avoid really *all* use of self.foreward_key_event() if the option self._avoid_forward_key_event is True
- Avoid verbatim bidi formatting characters in the source code
* Sun Oct  8 2023 Marguerite Su <i@marguerite.su>
- fix factory build:
  * ibus-typing-booster-libX11-1.8.7.patch
  * libX11-data dropped some compose sequences in en_US locale
    due to xkeyboard-config changes in version 1.8.7 (commit af2b6dfa)
  * so some itb tests are not valid any more.
* Mon Oct  2 2023 maiku.fabian@gmail.com
- Update to 2.24.2
- improve _return_false() and remove _commit_or_forward_key_event_or_return_false()
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/463)
- Make characters for Biángbiángmiàn easily searchable
- emoji-picker: Update default for current Unicode release 15.1
* Tue Sep 12 2023 maiku.fabian@gmail.com
- Update to 2.24.1
- Support several backends for playing sounds
  (Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=2237675)
- Update UnicodeData.txt to current Unicode 15.1.0
  and emoji data files to current Unicode 15.1
- Update emoji annotations from CLDR
* Fri Sep  1 2023 maiku.fabian@gmail.com
- Update to 2.24.0
- Implement “commit_and_forward_key” command
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/461)
- m17n-lib interface: transliterate “produced” part and “preedit” separately
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/460)
- Update emoji annotations from CLDR
* Thu Aug 10 2023 maiku.fabian@gmail.com
- Update to 2.23.4
- Support msymbol 'S-C-Return' as a commit to preedit key
  (Resolves https://github.com/mike-fabian/ibus-typing-booster/issues/457).
  Needed by hi-itrans.mim, hi-optitransv2.mim, kn-optitransv2.mim,
  mr-gamabhana.mim, sa-itrans.mim, sa-vedic-itrans.mim
- Remove useless m4/{Makefile.am,as-version.m4}
- Update emoji annotations from CLDR
- Update UnicodeData.txt to current Unicode 15.1.0 draft
  (https://www.unicode.org/Public/draft/UCD/ucd/UnicodeData.txt)
- Update emoji data files for current Unicode 15.1 DRAFT
  (https://www.unicode.org/Public/draft/UCD/ucd/emoji/emoji-data.txt
  https://www.unicode.org/Public/draft/UCD/ucd/emoji/emoji-variation-sequences.txt)
* Thu Aug  3 2023 maiku.fabian@gmail.com
- Update to 2.23.3
- Translation update from Weblate (tr 100%%)
* Mon Jul 31 2023 maiku.fabian@gmail.com
- Include inscript2 input methods only for suse_version < 1550
  i.e. do not include it on Tumbleed anymore. Because Tumbleweed
  has m17n-db-1.8.2 which has the inscript2 input methods already.
* Sun Jul 30 2023 maiku.fabian@gmail.com
- Update to 2.23.2
- Move self._gsettings.connect('changed', self.on_gsettings_value_changed)
  in __init__() *after* defining self._set_get_functions
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/454)
  (Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=2171140)
- Translation update from Weblate (ar 100%%)
- Update emoji annotations from CLDR
* Mon Jul  3 2023 maiku.fabian@gmail.com
- Update to 2.23.1
- Translation update from Weblate (pl 100%%)
- Adapt some test cases to changes in enchant
* Thu Jun 29 2023 maiku.fabian@gmail.com
- Update to 2.23.0
- Translation update from Weblate (de 100%%, ka 100%%, nl 100%%, sv 100%%, uk 100%%)
- configure.ac: add a warning about not using /usr/local as the prefix
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/444)
- Add an option to convert language specific digits to ASCII
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/445)
- Strip entered autosettings value for boolean values
- Update emoji annotations from CLDR
* Tue May  9 2023 maiku.fabian@gmail.com
- Update to 2.22.5
- Remove `xml:lang="en"` from the screenshots in appdata.xml
  (See: https://github.com/ximion/appstream/issues/494)
- Improve regexp for parsing description out of of .mim files
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/440)
- Setup tool: scale input method icons correctly
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/441)
- Update emoji annotations from CLDR
- Get version information of m17n-db
  (Needed for test cases depending on the version of m17n-db)
- Skip m17n_translit test cases when m17n-db is too old
* Mon Apr 24 2023 maiku.fabian@gmail.com
- Update to 2.22.4
- Return empty program_name and window_title in get_active_window_xprop()
  when xprop results are unexpected
  (Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=2175009)
- Update emoji annotations from CLDR
* Fri Apr 14 2023 maiku.fabian@gmail.com
- Update to 2.22.3
- Apply workaround for committing multiline strings only for '^gtk3-im:(firefox|thunderbird)', i.e. not on Wayland
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/438)
* Mon Apr  3 2023 maiku.fabian@gmail.com
- Update to 2.22.2
- Translation update from Weblate (ka 100%%, sw 99.5%%)
* Tue Feb 28 2023 maiku.fabian@gmail.com
- Update to 2.22.1
- Translation update from Weblate (sv 100%%)
- Fix input of '_' and emoji lookup using '_' for the French BÉPO layout
  and the German neo2 layout
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/432)
* Mon Feb 27 2023 maiku.fabian@gmail.com
- Update to 2.22.0
- Translation update from Weblate (de 100%%, ja 37.8%%, nl 100%%, pl 100%%, tr 100%%, uk 100%%)
- Changing the order of dictionaries and input methods by keybinding
  should not be permanent when autosettings for dictionaries or
  keybindings are applied
- Add a GUI in the setup tool for the autosettings
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/423)
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/328)
- Update emoji annotations from CLDR
* Mon Feb 20 2023 maiku.fabian@gmail.com
- Update to 2.21.4
- Memoize instances of the Dictionary class
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/425)
* Sun Feb 12 2023 maiku.fabian@gmail.com
- Update to 2.21.3
- Update emoji annotations from CLDR
- Translation update from Weblate (ka 100%%)
* Sun Feb 12 2023 maiku.fabian@gmail.com
- Update to 2.21.2
- Autoselect extremely likely candidates:
  Allow only adding of accents, never removing accents
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/420)
* Thu Feb  9 2023 maiku.fabian@gmail.com
- Update to 2.21.1
- Small performance tweak in detecting terminals
- Translation update from Weblate (nl 100%%, pl 100%%, sv 100%%, tr 100%%)
* Mon Feb  6 2023 maiku.fabian@gmail.com
- Update to 2.21.0
- Add an option to disable Typing Booster in terminals
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/414)
- Update emoji annotations from CLDR
- Add autosettings option (command line only at the moment, useful for
  https://github.com/mike-fabian/ibus-typing-booster/issues/328)
- Translation update from Weblate (de 100%%, uk 100%%)
* Mon Jan 23 2023 Andreas Schwab <schwab@suse.de>
- Use xvfb-run
* Thu Jan 19 2023 maiku.fabian@gmail.com
- Update to 2.20.0
- Allow predictions when 0 characters have been typed
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/268)
* Sun Jan  8 2023 maiku.fabian@gmail.com
- Update tarball to version with corrected changelog upstream
* Fri Dec 30 2022 maiku.fabian@gmail.com
- Update to 2.19.13
- Catch exception when user database is locked during shutdown
  (Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=215144)
* Thu Dec 29 2022 maiku.fabian@gmail.com
- Update to 2.19.12
- Try not to fail if the database contains invalid UTF-8 or is otherwise malformed
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/409)
* Tue Nov 29 2022 maiku.fabian@gmail.com
- Update to 2.19.10
- Save space when displaying compose completion in horizontal lookup tables
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/407)
* Mon Nov 28 2022 maiku.fabian@gmail.com
- Update to 2.19.9
- Emoji search: If search strings contain whitespace count as an exact match if
  all words match in any order
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/405)
- emoji-picker: If a search string contains non-whitespace characters, strip whitespace
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/404)
- emoji-picker: Put the first match in a search always into the clipboards automatically
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/402)
* Mon Nov  7 2022 maiku.fabian@gmail.com
- Update to 2.19.8
- Do not show automatic emoji predictions when OSK (on-screen-keyboard) is visible
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/398)
- Update emoji annotations from CLDR
- If a commit is triggered by a simple space, commit the space instead of forwarding it
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/397)
* Mon Oct 24 2022 maiku.fabian@gmail.com
- Update to 2.19.7
- Avoid inline completion when OSK (on-screen-keyboard) is shown
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/395)
- Do not reset input purpose on focus out
  (See: https://gitlab.gnome.org/GNOME/gnome-shell/-/issues/5966#note_1576732)
* Sat Oct 15 2022 maiku.fabian@gmail.com
- Update to 2.19.6
- Update emoji annotations from CLDR
- Avoid showing passwords in OSK buttons by disabling typing-booster
  in terminals when the on-screen-keyboard (OSK) is shown
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/393)
  (Requires: https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/2511)
- Translation update from Weblate (bn 100%% complete)
* Sun Oct  9 2022 maiku.fabian@gmail.com
- Update to 2.19.2
- Do not commit by index when OSK is visible
  (Resolves: https://gitlab.gnome.org/GNOME/gnome-shell/-/issues/5865)
- Translation update from Weblate (sw 100%% complete)
* Wed Oct  5 2022 maiku.fabian@gmail.com
- Update to 2.19.1
- Update emoji annotations from CLDR
- Make search for input methods which contain uppercase in their names work
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/387)
- Translation update from Weblate (bn 73.8%% complete)
* Fri Sep  9 2022 maiku.fabian@gmail.com
- Update to 2.19.0
- Save horizontal space to make the new Georgian translations fit better
  on small screens
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/383)
- Make compose support work for sequences starting with keys other
  than Multi_key and dead keys
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/379)
- Update emoji annotations from CLDR
- Stop using deprecated keyword arguments “flags” and “message_format” when
  creating Gtk.MessageDialog()
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/377)
- Use ['ar-kbd', 'NoIME'] by default for all Arabic locales instead of just ['NoIME']
- Make it possible to set options for m17n input methods in the typing booster setup tool
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/360)
- Translation update from Weblate (ar 100%%, bn 67%%, de 100%%, nl 100%%, pl 100%%, sv 100%%, tr 100%%, uk 100%%)
* Thu Sep  1 2022 maiku.fabian@gmail.com
- Update to 2.18.10
- Add functions to get and set variables for m17n input methods
- Update emoji annotations from CLDR
- Translation update from Weblate (bn added 42%% complete)
- Test cases for bn-national-jatiya.mim
- Add more icons in different sizes to the appdata.xml files
- Stop calling self.set_wmclass('emoji-picker', 'Emoji Picker') (avoid deprecation warning)
* Sun Aug  7 2022 maiku.fabian@gmail.com
- Update to 2.18.9
- Make it possible to use custom labels for different dictionary matches
- Distinguish dictionary matches shown by flags in the candidate list if
  some flags are identical
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/358)
- Update emoji annotations from CLDR
* Wed Aug  3 2022 maiku.fabian@gmail.com
- Update to 2.18.7
- Use the environment variable DICPATH as well when searching for dicitonaries
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/357)
- Translation update from Weblate (sw updated to 100%%)
* Sat Jul 30 2022 maiku.fabian@gmail.com
- Update to 2.18.6
- Avoid selection changed events when clearing the shortcut treeview
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/355)
- Correctly remember how often user shortcuts were used
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/353)
- Update emoji data files for current Unicode 15.0 DRAFT
- Update UnicodeData.txt to UnicodeData-15.0.0d6.txt
- Update emoji annotations from CLDR
- Use AT-SPI first to get the active window only on wayland, on X11 use xprop immediately
- Translation update from Weblate (sv updated to 100%%)
- do not use appstream-util in the check section of the .spec file,
  appstream-util is unmaintained.
* Wed Jul 27 2022 maiku.fabian@gmail.com
- Update to 2.18.4
- Get program name of focused window if do_focus_id doesn’t provide that already
- Show lookup table *always* when display of related emoji or words is requested
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/350)
- Translation update from Weblate (nl updated to 100%%)
* Mon Jul 18 2022 maiku.fabian@gmail.com
- Update to 2.18.0
- Optionally show flags in the candidate list for dictionary matches
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/343)
- Update emoji annotations from CLDR
- Translation update from Weblate
  (de (100%%), es (93.7%%), pl (100%%), tr (100%%), uk (100%%))
* Wed Jul 13 2022 maiku.fabian@gmail.com
- Update to 2.17.1
- Translation update from Weblate (pt updated to 100%%)
* Thu Jul  7 2022 maiku.fabian@gmail.com
- Update to 2.17.0
- Improve “Automatically select the best candidate”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/285)
- Translation update from Weblate
  (de (100%%), pl (100%%), pt (30.3%%), tr (100%%), uk (100%%))
* Mon Jul  4 2022 maiku.fabian@gmail.com
- Update to 2.16.10
- Improve “Automatically select the best candidate”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/285)
* Mon Jun 27 2022 maiku.fabian@gmail.com
- Update to 2.16.7
- When the lookup table is hidden because of inline completion,
  ignore commands to commit candidates by their index
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/325)
- Add a command 'commit' with configurable key bindings
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/320)
- Translation update from Weblate (sw updated to 100%%)
* Thu Jun 23 2022 maiku.fabian@gmail.com
- Update to 2.16.5
- Use new pykakasi API instead of the deprecated v1.2 API.
- Fix typo in LOCALE_DEFAULTS for Korean. The default values
  for Korean were not applied because of this typo.
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/321)
- Improve and simplify setting input methods and dictionaries using new
  helper functions
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/318)
- self._is_candidate_auto_selected should only be true if no manual keys
  to select were pressed
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/319)
- Translation update from Weblate (it updated 93.6%% (205 of 219 strings))
* Mon Jun 20 2022 maiku.fabian@gmail.com
- Update to 2.16.3
- Add search entry for already defined custom shortcuts
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/312)
* Thu Jun 16 2022 maiku.fabian@gmail.com
- Update to 2.16.1
- Avoid using forward_key_event() in Gtk4 immodule automatically by checking for
  IBUS_CAP_SYNC_PROCESS_KEY (new, will start working for ibus >= 1.5.27)
- Udate the “Use inline completion” combobox in the setup tool when the
  gsettings value changes
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/313)
- Require Python >= 3.6 to build
- Add client detection code by Takao Fujiwara (will start working for ibus >= 1.5.27)
- If libvoikko.Voikko('fi') fails when initializing a Finnish dictionary,
  continue without voikko
- Always show standard lookup table for compose completions, never try inline completions
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/307)
- Update configure.ac for latest autoconf 2.71
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/309)
- Update emoji annotations from CLDR (oc.xml is new)
- Translation update from Weblate (fr updated)
* Tue Jun  7 2022 maiku.fabian@gmail.com
- Update to 2.16.0
- Make it possible to use inline completion without automatic fallback to a candidate list
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/266)
  Now the inline completion option has 3 values:
  • No
  • Yes, with fallback to popup
  • Yes, without fallback to popup
  When choosing “Yes, with fallback”, the behaviour is as it used to be
  when the old checkbox was on: the completion is shown inline if this
  is possible without changing the already typed string in the preedit,
  if this is not possible, a popup candidate list is automatically shown
  instead as a fallback.
  When choosing “Yes without fallback to popup”, a popup candidate list
  is never shown automatically as a fallback but only when explicitely
  requested by typing the key bound to the command
  “select_next_candidate” (By default this is the Tab key).
  When updating to the new release with this new option, the value of
  the old checkbox gets lost. I.e. no matter whether the user had the
  inline completion option checked or not checked before the update,
  after the update the value for “inline completion” reverts to the
  default “No”. So if one was using “inline completion” before the
  update, one has to switch it on again after the update.
- Fix itb_emoji.find_cldr_annotation_path() (It always found a
  match even when the fallback went through all the way to
  'en', therefore all dictionaries were shown as supporting
  emoji in the setup tool)
- Update emoji annotations from CLDR (oc.xml is new)
- Translation update from Weblate (de (100%%), jp (36.9%%), nl (100%%),
  pl (100%%), tr (100%%), uk (100%%) updated)
* Thu May 12 2022 maiku.fabian@gmail.com
- Update to 2.15.27
- If an emoji is duplicated as a text candidate, use only the
  emoji candidate and increase its score
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/289)
- Update emoji annotations from CLDR
- Translation update from Weblate (sv updated to 100%%, sw updated to 100%%)
* Thu Mar  3 2022 maiku.fabian@gmail.com
- Update to 2.15.25
- Translation update from Weblate (de, fa, nl, pl, tr, uk updated)
- Make emoji and unicode symbol trigger key configurable
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/279)
- Do not commit if a key triggering a commit is swallowed by transliteration
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/281)
- Elide extremly long comments in the lookup table
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/280)
* Sun Feb 27 2022 maiku.fabian@gmail.com
- Update to 2.15.22
- Translation update from Weblate
  (ca, de, es, fr, nl, pl, pt, pt_BR, sv, tr, uk, zh_CN, zh_TW updated)
- Add a “Restore all defaults” button to the setup tool
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/272)
- Allow capital letters and accents in user shortcuts
- Make user shortcuts containing punctuation possible
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/271
- Do not record stuff to user database when itb_util.InputHints.PRIVATE is set
- Update emoji annotations from CLDR
* Sun Jan 30 2022 maiku.fabian@gmail.com
- Update to 2.15.16
- Ignore MOD3_MASK (“Usually” Scroll Lock) when matching key bindings
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/270)
- When a Modifier key release matches a hotkey command, return False not True.
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/269)
- Update emoji annotations from CLDR
- Update UnicodeData.txt UnicodeData-15.0.0d3.txt
* Mon Jan 17 2022 maiku.fabian@gmail.com
- Update to 2.15.15
- Translation update from Weblate (fr updated to 100%%)
* Mon Jan  3 2022 maiku.fabian@gmail.com
- Update to 2.15.14
- Update emojione.json file to new version emoji.json
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/262)
- Spellchecking during emoji search only for words with more then 5 letters
- Update emoji annotations from CLDR
- When emoji search via codepoint matches, increase the score of the code point match
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/263)
- Translation update from Weblate (cs updated)
- Skip Czech hunspell enchant test by removing myspell-cs_CZ from
  the BuildRequires (Something seems to have changed in the Czech dictionary
  on openSUSE).
* Sun Nov 28 2021 maiku.fabian@gmail.com
- Update to 2.15.11
- Use @functools.lru_cache(maxsize=None) decorator for remove_accents()
  (Makes everything 30%%-40%% faster)
- Add sorting option to tabstatistics
* Tue Nov 23 2021 maiku.fabian@gmail.com
- Update to 2.15.7
- Convert user database context to lower case and accents removed
  while reading training data
- Make the context in the database case insensitive and accent insensitive
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/256)
- Test cases for the sqlite database
- Allow cleanup_database() to cleanup an in memory database when doing unit tests
- Allow only lower case user shortcuts
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/255)
- Add function to return number of rows in the database for debugging and testing
- Allow to read training data from file when database is empty,
  allow reading from .gz files
* Fri Nov 19 2021 maiku.fabian@gmail.com
- Update to 2.15.3
- Title case all candidates if input_phrase is in title case
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/253)
* Tue Nov 16 2021 maiku.fabian@gmail.com
- Update to 2.15.0
- Make matching in the database case insensitive
  (https://github.com/mike-fabian/ibus-typing-booster/issues/251)
- Remove accents for “input_phrase” when learning from a text file
  (https://github.com/mike-fabian/ibus-typing-booster/issues/252)
- Make matching in dictionaries case insensitive
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/251)
- Cleanup user database when Typing Booster starts
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/239)
  Also use the sqlite3 “VACUUM” command to rebuild the database
  file, repacking it into a minimal amount of disk space
- Add tabstatistics.py, command line tool to display some information
  about the database contents
- Use python3-pycountry as a fallback to langtable
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/250)
- Add “Recommends: python3-langtable” to make the setup tool look nicer
  and the search for dictionaries and imes better
- Add “Recommends: python3-regex” to use better regexpressions if available
* Wed Sep 29 2021 maiku.fabian@gmail.com
- Update to 2.14.13
- Skip emoji tests which rely on the enchant results if enchants results change
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/244)
- Make it possible to remove unwanted compose sequences by using
  an empty replacement text
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/245)
- The 🏴‍☠️ “pirate flag” needs a U+FE0F after the final character to be fully qualified
- Update data files for Unicode 14.0.0
* Tue Sep 14 2021 maiku.fabian@gmail.com
- Update to 2.14.12
- Add some extra logging for the emoji tests
- Add 'G-_' to 'G- ' as exceptions which must not trigger commits but
  insert into the preedit
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/243)
- Update emoji annotations from CLDR
* Thu Sep  2 2021 maiku.fabian@gmail.com
- Update to 2.14.10
- Fix “Inconsistency when typing digits in Compose”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/238)
- Fix “Toggling input mode on/off does not work when a compose sequence is in progress”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/237)
- Toggling input mode off should not throw away the current input
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/236)
* Mon Aug 30 2021 maiku.fabian@gmail.com
- Update to 2.14.8
- Translation update from Weblate (ca, es, it updated)
- Update emoji annotations from CLDR
- Add IBus.KEY_KP_Decimal and IBus.KEY_period as a normal/keypad equivalence pair
- get_string_from_lookup_table_cursor_pos() should return the string in NFC
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/234)
- If an exception happens when trying to play a sound, catch it.
- Change default input method for pa from “pa-inscript2” to “pa-inscript2-guru”
- Make appearance tab narrower if possible (helps especially for the French translations)
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/230)
- Spellchecking the preëdit should only spellcheck the part of the preedit which is a word
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/229)
* Sun Aug 22 2021 maiku.fabian@gmail.com
- Update to 2.14.4
- Translation update from Weblate (de, nl, pl, sv, tr, uk updated to 100%%)
- Update emoji annotations from CLDR
- Treat typing space within a preedit similar to typing Return within a preedit
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/223)
- When a key triggers a commit while no candidate is selected, the cursor
  should **always** be corrected leftwards
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/227)
- When committing with Return inside a preedit, database recording and
  pushed context is wrong
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/226)
- Fix a typo which caused “\n” to be committed where “\t” should have been committed.
- Remove spaces in lookup representation of compose completions
- If a keypad key makes compose sequence invalid, try sequence with
  regular keys instead (And the other way round)
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/224)
- Make typing Return or KP_Enter inside a preedit more reliable
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/222)
- Show input method icons in the setup tool if an icon is available
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/213)
- Rename option “Arrow keys can reopen a preedit” to “Enable reopening preedits”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/212)
* Thu Aug 12 2021 maiku.fabian@gmail.com
- Update to 2.14.0
- Update inscript2 input methods to: inscript2-20210812.tar.gz
- Delete m17n-db-1.8.0-inscript2-mni-sat.patch, not necessary anymore
  because of the new inscript2-20210812.tar.gz tarball
- Translation update from Weblate (de, nl, pl, sv, tr, uk updated to 100%%)
- Update emoji annotations from CLDR
- Improve code to determine the default dictionaries and input methods
  for the current locale
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/209)
- Improve behaviour of key combinations which normally select text when a preëdit is open
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/210)
- Show possible compose completions on request
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/208)
- When setting self._input_mode to False (direct input),
  set self._hide_input to False as well
- Never mix context from surrounding text with remembered context
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/204)
- Rename the option “Use a workaround for a bug in Qt im module” to
  “Avoid using the forward_key_event() function”
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/200)
- Handle End, Home, KP_End, KP_Home also as commit trigger keys.
  For normal preedits *and* for compose preedits.
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/199)
- Improve typing space or Tab when the cursor is not at the end of the preedit
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/198)
- Completly new implementation of reopening the preedit on
  arrow-keys, BackSpace and Delete. Should be much more reliable.
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/196)
- Special handling of Left and BackSpace when a candidate is manually selected
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/178)
* Tue Aug  3 2021 maiku.fabian@gmail.com
- Update to 2.13.1
- Translation update from Weblate (de, nl, pl, tr, uk updated to 100%%)
- Don’t skip reopening a preëdit when NumLock is on
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/178)
- Make searching for the “Others” input methods possible in the language
  of the current locale
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/190)
- Don’t loop over the missing dictionaries when installing, install all in one go
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/189)
- When adding an input method, searching for localized language names, endonyms,
  and English language names should work
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/188)
- When adding a dictionary, searching for the language endonym should always work
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/187)
* Sat Jul 31 2021 maiku.fabian@gmail.com
- Update to 2.13.0
- Translation update from Weblate (de, tr, uk updated to 100%%)
- Use colour for the compose part of preedit
  (Resolves: Use colour for the compose part of preedit)
- When a compose sequence becomes invalid, don’t throw it away
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/180)
- Cancelling a compose sequence should not beep
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/179)
- Don’t spell check the preedit while a compose sequence is in progress
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/181)
* Wed Jul 28 2021 maiku.fabian@gmail.com
- Update to 2.12.1
- Starting a compose sequence while a candidate is selected should
  append to the selection
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/175)
- Translation update from Weblate (de, nl, pl, tr, uk all updated to 100%%)
- Fix typo in translatable message (Thanks to Yuri Chornoivan)
- Add a few more combining chars for dead keys to the list (Thanks to Matthias Clasen)
- Reduce grid row spacing from 10 to 5 in the setup tool
* Tue Jul 27 2021 maiku.fabian@gmail.com
- Update to 2.12.0
- Use the dead keys added recently to ibus as soon as they become available
  by an ibus update
  (see: https://github.com/ibus/ibus/commit/3e2609e68c9107ce7c65e2d5876bfdc9f0f8c854)
- Make Compose preedit less intrusive, show compose key only in
  the middle of the sequence or when it is the only key so far
- Use · U+00B7 MIDDLE DOT instead of ⎄ U+2384 COMPOSITION SYMBOL to display
  Multi_key in pre-edit.
- Add an option to play a sound on error (for example invalid compose sequence)
- Do not include the system compose files unconditionally if a user compose file exists
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/170)
- Add option to choose whether to start up in direct input mode
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/169)
- Change default input methods for Indian locales to inscript2
* Thu Jul  8 2021 maiku.fabian@gmail.com
- Resolves: rhbz#1978361
  (itb_emoji.py:44:<module>:ModuleNotFoundError: No module named 'packaging')
* Mon Jun 21 2021 maiku.fabian@gmail.com
- Update to 2.11.5
- Resolves: rhbz#1970626 Ensure enum.Flag's obj._value_ is an integer
  Thanks to Miro Hrončok!
- Use version.parse from packaging instead of LooseVersion from distutils.version
  (To fix a deprecation warning, see: https://www.python.org/dev/peps/pep-0632/)
- Update py-compile to the version from automake-1.16
  (To fix DeprecationWarning: the imp module is deprecated in favour of
  importlib and slated for removal in Python 3.12;)
* Thu Apr 29 2021 maiku.fabian@gmail.com
- Update to 2.11.4
- In main.py “import factory” only when the --xml option is not used
  Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=1711646
- Limit the “capitalize” case mode used in auto-capitalization to the
  first index in a string
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/16
* Mon Apr  5 2021 maiku.fabian@gmail.com
- Update to 2.11.2
- Improve the handling of typing digits into the preedit
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/164
- Make the keybindings treeview also sortable by clicking the column headers
- Make custom shortcut treeview sortable by clicking on the column headers
- Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/163
- Don’t use surrounding text if InputPurpose.TERMINAL is set
* Thu Mar 11 2021 maiku.fabian@gmail.com
- Update to 2.11.0
- Use sensitivity feature of buttons in the setup tool tab where shortcuts are defined
- Don’t let dialog action area of setup tool expand.
- Improve the setup tool to make it possible to enter multi-line expansions of shortcuts
- Resolves https://github.com/mike-fabian/ibus-typing-booster/issues/158
- Elide extremely long candidates in the lookup table in the middle.
- If a candidate contains newlines, replace the newlines with arrows in the lookup table.
- If a commit string contains new-lines, commit it in several chunks
  and forward Return between the chunks.
- Update emoji annotations from CLDR
- Put the remote icon back in emoji-picker.appdata.xml, it was a
  false positive by appstreamcli
- Translation update from Weblate (pt_PT updated, 100%% complete now)
- Skip the inscript2 test cases if these transliterations are not available.
* Wed Feb 17 2021 maiku.fabian@gmail.com
- Update to 2.10.5
- Run the voikko tests only for libvoikko version >= 4.3
- Adapt voikko test cases to the newest voikko version
  libvoikko-4.3-3, python3-libvoikko-4.3-3, voikko-fi-2.4-3
- Log a warning when language is “fi” and “import libvoikko” failed
- Return an empty list [] in spellcheck_suggest_voikko() when libvoikko was not imported
- Update emoji annotations from CLDR, switching “no” and “nb”
  See: https://unicode-org.atlassian.net/browse/CLDR-2698
- Remove icon in emoji-picker.appdata.xml (to avoid warnings
  from appstream-util and appstreamcli).
* Tue Feb  2 2021 maiku.fabian@gmail.com
- Update to 2.10.4
- Use “from unittest import mock” instead of just “import mock”.
- Update emoji annotations from CLDR
- Translation update from Weblate for zh_CN (still 100%% complete)
* Sun Jan 24 2021 maiku.fabian@gmail.com
- Update to 2.10.3
- Update emoji annotations from CLDR
- Translation update from Weblate for ja, zh_CN
  (zh_CN is 100%% complete now)
* Thu Dec 17 2020 maiku.fabian@gmail.com
- Update to 2.10.2
- Add vi-telex to the default input methods for vi_VN locale
- Enable Unicode 13.1 Emoji in emoji-picker by default
- Update emoji data to Unicode 13.1
- Translation update from Weblate for zh_CN
* Tue Nov 10 2020 maiku.fabian@gmail.com
- Update to 2.10.1
- Use IBus.InputHints.{UPPERCASE_CHARS,UPPERCASE_WORDS,LOWERCASE}
- Add utility to manually test input purpose and input
- Improve handling of input purpose and input hints
- Add compatibility enum classes InputPurpose and InputHints
- Add type hints
- Change default for emoji_unicode_min to 0.0
  (fixes emoji omitted from browsing in emoji-picker)
* Mon Oct 19 2020 maiku.fabian@gmail.com
- Update to 2.10.0
- Add option to automatically capitalize after punctuation
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/96)
- Don't record in user database when stripped_input_phrase or
  stripped_commit_phrase are emty
- When interactively deleting a candidate from the user database,
  remove all case modes
- Add 4 more characters ÞĦŊŦ to get special treatment in remove_accents()
- Translation updates from Weblate for ca, es, fr, it, ja, nl, sv
* Thu Oct  8 2020 maiku.fabian@gmail.com
- Update to 2.9.9
- Fix typo in variable name in do_reset()
- KP_Delete should be handled the same way as Delete
- Translation update form Weblate for de, he, pl, tr, uk
* Tue Oct  6 2020 maiku.fabian@gmail.com
- Update to 2.9.8
- Prevent also Delete from reopening a preedit when the option
  “Arrow keys can reopen a preedit” is off
- When the input is empty, Escape should be passed through,
  not inserted into the preedit
- Fix itb_util.tokenize(): if the input is only whitespace,
  the return should be an empty list
- Don’t clear context after typing Return, KP_Enter, ISO_Enter
- Improve behaviour of case modes
- Update emoji annotations from CLDR
* Mon Sep  7 2020 maiku.fabian@gmail.com
- Update to 2.9.7
- Add commands “next_case_mode” and “previous_case_mode”
  with configurable key bindings
- Better hot key handling for modifier keys like Shift_L, …
- Use labels 1, 2, 3, … for the lookup table instead of 1., 2., 3., …
- Update emoji annotations from CLDR
* Thu Aug 27 2020 maiku.fabian@gmail.com
- Update to 2.9.6
- Make translations of 'Edit key bindings for command “%%s”' work
- Don't hide emoji-picker.desktop from AppStream (by Gunnar Hjalmarsson)
- Translation update from Weblate for pt_BR, sv (100%%)
* Wed Aug  5 2020 maiku.fabian@gmail.com
- Update to 2.9.5
- Treat characters 'ÅåÄäÖö' as special when matching in the Swedish dictionary
  (Resolves: http ://github.com/mike-fabian/ibus-typing-booster/issues/126)
- Update emoji annotations from CLDR
- AppStream tweaks by Gunnar Hjalmarsson
- Translation update from Weblate for ca, de, es, sv
* Tue Jul 14 2020 maiku.fabian@gmail.com
- Update to 2.9.4
- Add emoji-picker.appdata.xml
- Fix warnings and errors in typing-booster.appdata.xml
- Update emoji annotations from CLDR
- Support %%S expansion in include statements in compose files
- Translation update from Weblate for fr, he, hu, zh_CN
* Mon Jun 22 2020 maiku.fabian@gmail.com
- Update to 2.9.3
- Translation updates from Weblate for he
- Fix wrong indentation of push_context() in _commit_string()
* Mon Jun  8 2020 maiku.fabian@gmail.com
- Update to 2.9.2
- Translation updates from Weblate for es
- Ignore invalid compose sequences when reading compose files
- Update emoji annotations from CLDR
* Wed May 27 2020 maiku.fabian@gmail.com
- Update to 2.9.1
- Translation updates form Weblate for fr, nl, zh_TW
- Make keyboard shortcuts like Control+a work on non-ASCII keyboard layouts
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/107)
- Fix broken adding of key bindings
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/109)
* Wed May 20 2020 maiku.fabian@gmail.com
- Update to 2.9.0
- Translation updates from Weblate for de, ja, pl, tr, uk, zh_CN
- Update ibus-typing-booster.pot (Some new translatable strings, tooltips for 2 new buttons)
- Improve matching of keybindings, consider IBus.ModifierType.MODIFIER_MASK
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/94)
- Show the list of dictionaries in the setup tool only if it is more than just ['None']
- If a real dictionary is added in the setup tool, remove dummy dictionary 'None'.
- Add black flag for the special dummy dictionary 'None'
- Add doctests to check that the special dictionary 'None' is handled correctly
- When the list of imes or dictionaries is emptied by the user, set it to 'NoIME' or 'None'
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/98)
- Add "Set to default" buttons for the list of input methods and dictionaries
- Remove the special candidate which is shown when a dictionary is missing
* Sun May  3 2020 maiku.fabian@gmail.com
- Update to 2.8.3
- Save default dictionaries and input methods when making the lists
  empty in the setup tool
- Fix reading “include” instructions in Compose files and observe XCOMPOSEFILE
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/93)
- Fix right-to-left detection for LC_MESSAGES=C
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/97)
- GUI tests added thanks to Takao Fujiwara
- Update UnicodeData.txt to Unicode 13.0.0
- Translation updates for it, hu, tr, pt_BR
* Tue Mar 31 2020 maiku.fabian@gmail.com
- Update to 2.8.2
- Translation updates from Weblate for ar, tr
- Update emoji annotations from CLDR
* Thu Feb 27 2020 maiku.fabian@gmail.com
- Update to 2.8.1
- Prevent also BackSpace from reopening a preedit when the option
  “Arrow keys can reopen a preedit” is off
- Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/87
- Resolves: rhbz#1637647
- Translation updates from Weblate for es, tr, he
- Update emoji annotations from CLDR
* Tue Feb  4 2020 maiku.fabian@gmail.com
- Update to 2.8.0
- Translation updates from Weblate for ca, de, es, fr, nl, pl, uk
- Update emoji annotations from CLDR
- Update emoji data to Unicode 13.0 final
- New option to choose whether spellchecking is done on the preedit
  and which colour to use
- Spellcheck typed string in preedit and colour it if it is likely to be misspelled
- More test cases for spellchecking and spellchecking suggestions
- Restructure code for spellchecking and spellchecking suggestions
* Fri Jan 24 2020 maiku.fabian@gmail.com
- Update to 2.7.7
- Translation updates from Weblate for es, de, pl, he, fr, uk, tr, nl
- Generate README.html and README from README.md
- A thorough upgrade to README.md
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/pull/74
- Set button label of google application credentials button correctly
  Resolves: rhbz#1793460
- Make si-wijesekera the default input method for si_LK.UTF-8 locale
- Add another test case for libvoikko spellchecking together with
  en_GB spellchecking
* Sun Jan  5 2020 maiku.fabian@gmail.com
- Update to 2.7.6
- Use included fi_FI.dic for Finnish word suggestions
- Add Finnish ispell dictionary fi_FI.dic
- Minor translation updates from Weblate for pl, tr, zh_CN
* Wed Dec 18 2019 maiku.fabian@gmail.com
- Update to 2.7.5
- Add libvoikko support for Finnish
- Add support for (almost) arbitrary dead key sequences
  (suggested by Marko Myllynen)
* Sat Dec 14 2019 maiku.fabian@gmail.com
- Update to 2.7.4
- Updated Portuguese (Brazil) translations from Weblate (100.0%% translated)
- Updated Turkish translations from Weblate (100.0%% translated)
- Remove weird spelling “preëdit” from messageid
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/62)
- Update emoji annotations from CLDR
* Mon Nov 25 2019 maiku.fabian@gmail.com
- Update to 2.7.3
- Correct release dates of Unicode 12.0.0 and 12.1.0 in emoji_picker.py
- Add workaround if key codes cannot be found for key values
  (workaround for big endian platforms)
- Fix race condition in itb_util.xdg_save_data_path()
  Resolves: rhbz#1770072
  Resolves: rhbz#1713963
  Resolves: rhbz#1764520
  Resolves: rhbz#1768016
- Another fix for right-to-left languages: fix wrong order of globe emoji
- Small fix in parsing emoji-test.txt which slightly changes the emoji sorting order
- Adapt parsing of the emoji data files to the changes in Unicode 13.0
- Fix emoji test cases for new emoji data files for Unicode 13.0
- Update emoji data to current Unicode 13.0 draft
- Add fa, it, tr to LINGUAS
- Updated Odia translations from Weblate (53.4%% translated)
- Updated Czech translations from Weblate (100.0%% translated)
- Updated Catalan translations from Weblate (17.1%% translated)
- Added Turkish translations from Weblate (100.0%% translated)
- Added Italian translations from  Weblate (5.2%% translated)
- Portuguese (Portugal) translations moved from pt_PT to pt (23.8%% translated)
- Update French translations from Weblate (100.0%% translated)
- Added Persian translations from Weblate (0%% translated)
* Wed Nov  6 2019 maiku.fabian@gmail.com
- Update to 2.7.2
- Fix display for right-to-left languages in the dictionaries and
  input methods tab in the setup tool
- Added Swahili translations from Weblate (30.1%% translated)
- Added Traditional Chinese translations from Weblate (0.5%% translated)
- Added Portuguese (Portugal) translations from Weblate (23.8%% translated)
- Update Hebrew translations from Weblate (100%% translated)
- Update Arabic translations from Weblate (100%% translated)
- Update Odia translations from Weblate (44.0%% translated)
- Update Spanisch translations from Weblate (93.3%% translated)
* Thu Oct 31 2019 maiku.fabian@gmail.com
- Update to 2.7.1
- Update Chinese (Simplified) translations from Weblate (13.5%% translated)
- Update Spanish translations from Weblate (92.2%% translated)
- Update Catalan translations from Weblate (12.4%% translated)
- Add Hebrew translation from Weblate (67.4%% translated)
- Add Arabic translation from Weblate (28.0%% translated)
- Update Ukrainian translations from Weblate (100.0%% translated)
- Update German translations from Weblate (100.0%% translated)
- Update Japanese translations from Weblate (35.2%% translated)
- Update French translations from Weblate (93.8%% translated)
- Add Hungarian translation from Weblate (58.0%% translated)
- Add Odia translations from Weblate (2.6%% translated)
- Improve compose file parsing to get results containing \" correct
- More test cases for compose sequences
- Change README.md to refer to Weblate for translations instead of Zanata
- Fix display of code points in emoji-picker when running in or_IN.UTF-8 locale
* Fri Oct 18 2019 maiku.fabian@gmail.com
- Update to 2.7.0
- Add support for compose sequences
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/47
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/36
- Test cases for compose support
- When using doctest: log to stderr and set logging level to DEBUG
- Properly close file handles when loading hunspell dictionaries
* Fri Oct 11 2019 maiku.fabian@gmail.com
- Update to 2.6.8
- Quote the tables for the key and mouse bindings in the README.md as code
- Do not hardcode the list of useful m17n input methods
- Use LOGGER.exeption() in exception handlers
- Use python logging module with log file rotation instead of writing to stdout/stderr
- Fix set_preedit_underline() with parameter update_gsettings=True
- Fix mni-inscript2-{beng,mtei}.mim and sat-inscript2-{deva,olck}.mim
  (m17n-db-1.8.0-inscript2-mni-sat.patch)
* Tue Oct  1 2019 maiku.fabian@gmail.com
- Update to 2.6.7
- If the first candidate is exactly the same as the typed string
  prefer longer candidates (Extends inline completions automatically)
- Move README to README.md and use some markdown to make it look better on github
- When showing similar emoji in the lookup table, show the list of keywords
  which matched only when debugging is on
- Update emoji annotations from CLDR
- More unittests, restructure test files, move some doctests to unittests
- Add a utility class KeyvalsToKeycodes to find ibus key codes
  instead of hardcoding them
- Add ceb to CLDR_ANNOTATION_FILES
* Wed Sep 11 2019 maiku.fabian@gmail.com
- Update to 2.6.6
- When checking whether to show inline completion, normalize the first candidate as well
- Two more test cases in hunspell_suggest.py
- Make it work correctly with newer French hunspell dictionaries
- Skip some unittests when dictionaries or python modules needed are not installed
- Update emoji annotations from CLDR
- Add more test cases to m17n_translit_test.py for si-sayura.mim
* Wed Aug 28 2019 maiku.fabian@gmail.com
- Update to 2.6.5
- Added Dutch translation (Thanks to Heimen Stoffels)
- Add si-sayura to the list of M17N input methods
* Wed Jul 17 2019 maiku.fabian@gmail.com
- Update to 2.6.4
- Update translations from zanata (cs updated, now 100%% complete)
- Do not crash if initializing enchant or pyhunspell fails,
  continue without spellchecking (Currently, on openSUSE Tumbleweed,
  python3-pyenchant seems broken)
- Try to install myspell-xx_YY packages instead of hunspell-xx package on SUSE
- Fix loading of cldr annotations when the .xml files are zipped
- Add JoyPixels to good_emoji_fonts list
- Add "Requires:  enchant-1-backend" to work around a bug with python3-enchant
* Wed Jun 19 2019 maiku.fabian@gmail.com
- Update to 2.6.3
- Performance improvement of around 30%% in EmojiMatcher._match()
- Tiny performance improvement in itb_emoji.py _set_seq1()
* Wed Jun  5 2019 maiku.fabian@gmail.com
- Update to 2.6.2
- Emoji ZWJSequence “people holding hands” is 12.0, not 10.0
- Update emoji annotations from CLDR
- icons: Regenerate with proper transparency (Thanks to FeRD (Frank Dana))
- Remove enable-background from icon SVG (Thanks to FeRD (Frank Dana))
- Update UnicodeData.txt to current Unicode 12.1.0
* Mon May  6 2019 maiku.fabian@gmail.com
- Update to 2.6.1
- Support emoji presentation and text presentation in emoji-picker
- Improve itb_emoji.py to also support text presentation of emoji
- Update emoji annotations from CLDR
* Sun Mar  3 2019 maiku.fabian@gmail.com
- Update to 2.6.0
- Update translations from zanata (de updated)
- Update emoji annotations from CLDR
- When Left or BackSpace trigger a commit, forward Left events only
  when no candidate was selected (i.e. the preëdit was committed)
- If a candidate is shown inline and *manually* selected, show the caret
  at the end of the candidate
- Right, Left, BackSpace, and Delete edit the preëdit only if no
  candidate is *manually* selected
- If an input char is typed while a candidate is *manually* selected,
  add that input to the candidate
- Change option name 'Add a space when committing by label or mouse'
  in setup tool
- Remove option “Use digits as select keys”
- Make key bindings to commit or remove candidates via label configurable
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/48)
- Multi word suggestions: Commit the current commit phrase and the
  previous phrase as a single unit as well
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/49)
- Fix wrong tooltip for “Automatically select the best candidate” option
- Let the tests produce verbose output
* Tue Feb 26 2019 Marguerite Su <i@marguerite.su>
- run time-consuming tests simutaneously via script
  or tumbleweed will fail due to OBS thought the job
  was stuck
* Mon Feb 18 2019 maiku.fabian@gmail.com
- Update to 2.5.3
- Update translations from zanata (ja, pl updated)
- Update emoji annotations from CLDR
- Use “NoIME” instead of “NoIme” as the internal name of the dummy input method
* Wed Feb  6 2019 maiku.fabian@gmail.com
- Update to 2.5.2
- Fix test case for selecting non existing candidates for Fedora rawhide
- Update UnicodeData.txt to current Unicode 12.0 draft
- Update emoji data to Unicode 12.0 final for 2019
- Update emoji annotations from CLDR
- Initialize self.dictionary_sub_properties_prop_list = [] in self._init_properties()
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/46)
- Fix test case for case mode change
- Improve filter for dictionary selection if langtable available
* Wed Jan 30 2019 maiku.fabian@gmail.com
- Update to 2.5.1
- Update translations from zanata (de, ja, fr, pl updated)
- Show also dictionary when “Show status in auxiliary text” is on
- Set notebook in setup tool to scrollable
- Make filter for dictionary selection work for language descriptions if langtable available
- Show names of languages and territories in setup tool if langtable is available
- Add missing flag for csb_PL
- Add option to automatically select the best candidate
- Pressing Shift should not immediately change the case mode of the candidates
* Mon Jan 21 2019 maiku.fabian@gmail.com
- Update to 2.5.0
- Update translations from zanata (de, ja, uk updated)
- Add a property menu for the highest priority dictonary
- Add a missing _update_preedit()
- When lookup is enabled by tab but the lookup table is empty,
  the first cancel should clear the input
- Reset self.is_lookup_table_enabled_by_tab and
  self.is_lookup_table_enabled_by_min_char_complete when input is cleared
- Get suggestions from hunspell dictionaries only for input
  which does not contain spaces
- Don’t reinitialize the dictionaries if only the order of the dictionaries has changed
- Add key bindings to change the priority of dictionaries
- Speech recognition input using Google speech-to-text
- Change the default input methods for as_IN, kn_IN, and ta_IN
- Make ur-phonetic the default input method for ur_IN and add en_GB dictionary to default
- Update emoji annotations from CLDR
- Add Recommends: python3-PyAudio (For voice recognition)
* Mon Dec 31 2018 maiku.fabian@gmail.com
- Update to 2.4.1
- Update translations from zanata (pl updated)
- Add direct input mode
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/25)
- Fix start of setup tool when libexedir is not /usr/libexec/
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/42)
* Thu Dec 20 2018 maiku.fabian@gmail.com
- Update to 2.4.0
- Update translations from zanata (de, es, fr, ja, pl, uk updated)
- Add new command 'toggle_hide_input' to hide the preëdit, lookup table, and auxiliary text
- Add an option to use preedit style only if lookup is enabled
- Add an option to choose the style of underlining the preedit
- Don’t try to record the first candidate when there is none
  after an automatic commit on focus out or reset
  (Resolves: rhbz#1659128)
- Add an option in the setup tool to set the debug level
- Move appearance related options to the new “Appearance” tab
- Add settings for colour and other appearance stuff
- Move “Dictionaries and input methods” Tab in the setup tool to the first position
- Update the shortcut hints in the tooltips when keybindings change
- Only show the label in the panel menus for emoji-mode and off-the-record-mode
- Don’t show the shortcut hints in the menu labels, takes too much space there.
- Update README because of the recent change to make keybindings configurable.
* Thu Dec 13 2018 maiku.fabian@gmail.com
- Update to 2.3.3
- Toggle candidates between 'title', 'upper', and 'lower' case
  when Shift is typed.
- Improve Spanish translation (Thanks to Ismael Venegas Castelló)
* Wed Dec 12 2018 maiku.fabian@gmail.com
- Update to 2.3.2
- Key bindings should match independent of whether
  Num Lock or Caps Lock are on or off.
* Sat Dec  8 2018 maiku.fabian@gmail.com
- Update to 2.3.1
- Update translations from zanata (cs, de, es, fr, ja, pl, pt_BR, uk, zh_CN updated)
- Avoid some PyGTKDeprecationWarnings
- Don’t show Unicode 12.0 draft emoji by default in emoji-picker
- Update emoji data to Unicode 12.0 draft
- Update emoji annotations from CLDR
* Wed Dec  5 2018 maiku.fabian@gmail.com
- Update to 2.3.0
- Update translations from zanata (de, ja, uk updated)
- Commit the current preëdit when the focus changes
- When preëdit empty or lookup table not enabled by key: clear the lookup table
- Make key bindings configurable
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/15)
- Correct tooltips for the “up” and “down” buttons for
  input methods dictionaries
* Wed Nov 28 2018 maiku.fabian@gmail.com
- Update to 2.2.1
- Update translations from zanata (pl, uk updated)
* Wed Nov 21 2018 maiku.fabian@gmail.com
- Update to 2.2.0
- Update translations from zanata (de updated)
- Save some screen space in the setup tool
- Add inline completion feature
- Tab should force a lookup when the minimum number of characters is not yet reached
* Mon Oct  8 2018 maiku.fabian@gmail.com
- Update to 2.1.3
- Update translations from zanata (uk updated)
* Mon Sep 24 2018 maiku.fabian@gmail.com
- Update to 2.1.2
- Update translations from zanata (de, pl updated)
- Add typing-booster.its and typing-booster.loc to avoid making the
  release descriptions and developer name in typing-booster.appdata.xml
  translatable.
- Remove code to check whether another instance of the setup tool is running.
- Add new option to avoid adding a space when committing by label or mouse
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/39)
- Update emoji annotations from CLDR
- Do not try to commit if index is >= the current number of candidates
  (Resolves: rhbz#1630349)
- Add test case for https://bugzilla.redhat.com/show_bug.cgi?id=1630349
* Wed Sep  5 2018 maiku.fabian@gmail.com
- Add appstream-glib and glib2 to BuildRequires (to run the tests
  in the check section of the spec file)
- validate the appdata.xml and desktop files in the check section
  of the spec file.
* Wed Sep  5 2018 maiku.fabian@gmail.com
- Update to 2.1.1
- Update translations from zanata (es updated, 100%% complete now)
* Tue Jul 24 2018 maiku.fabian@gmail.com
- Update to 2.1.0
- emoji-picker: Show a concise description of a selected emoji in the header bar
- Update the setup UI when settings are changed outside of the setup UI
- Migrate IBusConfig to GSettings (The old settings are
  unfortunately lost, so one has to open the setup tool
  and recreate ones favourite settings).
- Read emoji data files always in UTF-8
* Wed Jun 27 2018 maiku.fabian@gmail.com
- Update to 2.0.2
- Better Tab handling, use Tab to switch to the next candidate, not to commit
* Thu Jun 21 2018 maiku.fabian@gmail.com
- Update to 2.0.1
- Update translations from zanata (ja updated)
- Update emoji annotations from CLDR
- Fix some bugs in the usage of “prefix” for prefixes other than “/usr” (For FreeBSD)
- Make itb_util.get_ime_help() work on FreeBSD
- Update UnicodeData.txt to Unicode 11.0.0
- Remove useless 't-nil vi-base': 'vi-base.mim', from M17N_INPUT_METHODS
- Remove extra space in entry for sa-IAST input method to make it work
- Show in the setup tool in the input listbox whether minput_open_im() succeeded.
- Use the rocket icon emoji_u1f680.svg from the “Noto Color Emoji” font
* Mon May 28 2018 maiku.fabian@gmail.com
- Update to 2.0.0
- Update translations because of the merge of the engines (de, pl, uk updated)
- Update emoji annotations from CLDR
- Do not hardcode icon names in desktop files
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/17)
- Change the default for “Unicode symbols and emoji predictions” to “False”
- Merge all typing-booster engines into one
- Change the UI of the setup tool to make it possible to select
  multiple input methods and dictionaries
- Move the buttons to learn from a file and to delete learned data to the options tab
- Use the same “About” dialog in the setup tool as in emoji-picker
* Tue May 22 2018 maiku.fabian@gmail.com
- Refresh french translation (thanks to Thierry Thomas)
- Mark comments in the emoji-picker about dialog as translatable
* Mon May 14 2018 maiku.fabian@gmail.com
- Update to 1.5.37
- Update translations from Zanata (pl and uk updated)
- Make “Add direct input” option work correctly when
  “Remember last preedit input method” option is off
- Fix test case for Korean
- Rewrite setup UI completely in Python, without using Glade
- Fix format string in debug message when a dictionary .aff file has no encoding
  (Resolves: rhbz#1575659)
- Return False in read_training_data_from_file() if file cannot be opened
* Tue Apr 10 2018 maiku.fabian@gmail.com
- update to 1.5.36
- Make the default for self.show_status_info_in_auxiliary_text False
  (Resolves: rhbz#156435)
- Adapt hunspell_suggest.py to work with pyhunspell 0.5.4
* Tue Mar 13 2018 maiku.fabian@gmail.com
- update to 1.5.35
- Update translations from zanata (es, pl and uk updated)
- Update UnicodeData.txt to UnicodeData-11.0.0d13.txt
- Read also the emoji names from the emoji-test.txt file
- Update Unicode emoji data to a prerelease of Unicode Emoji Data 11.0
- Fix PyGTKDeprecationWarning: Using positional arguments with the
  GObject constructor has been deprecated.
- Add “Twemoji” as a good colour emoji font to the emoji-picker font list
- Don’t show the languages en_001 and  es_419 in the browsing treeview
- Use romaji=True by default in EmojiMatcher
- Update emoji annotations from CLDR
* Fri Jan  5 2018 bwiedemann@suse.com
- Use gzip -n to not include build timestamps in .gz headers
* Wed Nov 29 2017 badshah400@gmail.com
- Specfile cleanup:
  * Update source URLs; fedorahosted has been retired.
  * Fix package Group.
  * Run spec-cleaner for minor formatting clean-ups.
* Thu Oct  5 2017 maiku.fabian@gmail.com
- update to 1.5.34
- Update translations from zanata (cs new, de updated)
- Add some tooltips
- Add an option whether to use pango font fallback to emoji-picker
- Update emoji annotations from CLDR
- Add Recommends: google-noto-emoji-color-fonts
* Mon Sep 11 2017 maiku.fabian@gmail.com
- update to 1.5.33
- Update translations from zanata (es new)
- Install appstream metadata to /usr/share/metainfo/
- Update UnicodeData.txt to Unicode 10.0.0
- Fix test cases and kakasi support for the update of the
  emoji annotations from CLDR
- Update emoji annotations from CLDR
- Skip the emoji which already have skin tone modifiers
  in itb_emoji.emoji_by_label()
- Never load characters of Unicode categories “Cc”, “Co”,
  and “Cs” into the emoji dictionary
- Update emoji-data.txt to 5.0
* Mon Apr 24 2017 maiku.fabian@gmail.com
- update to 1.5.32
- Fix error when starting emoji-picker when the “recently-used” does not yet exist
- Update emojione.json to version 3.0
- Add the data from CLDR common/annotationsDerived
- Load also the CLDR annotations from “annotationsDerived”
* Tue Apr 18 2017 maiku.fabian@gmail.com
- update to 1.5.31
- Rename option --use_vs16 to --non_fully_qualified
  (effectivly reversing the default)
- Make description labels in info popover selectable to be able
  to copy and paste their contents
- Sort similar emoji with the same number of matching labels
  by cldr_order distance
- Map cldr subgroup 'person-sport' to emojione category 'activity'
- Make the categorie listings and the search work right
  when using --use_vs16
- Always store only non-fully-qualified emoji or emoji-sequences
  in the internal dictionary
- Update emoji annotations from CLDR
* Mon Apr  3 2017 maiku.fabian@gmail.com
- update to 1.5.30
- Update translations from zanata (de, pl, uk updated)
- Use string order as a fallback to cldr_order in category listings
- The rainbow flag should be a zwj sequence
- Also display the Unicode version in the emoji info popover
- When looking up emoji or other characters via Unicode codepoint,
  ignore surrogates and private use characters
- Show the fonts really used to render an emoji in the
  info popover for the emoji
- Fix typo in translatable string
- itb_emoji.py: Use CLDR order to sort the candidates and
  the similar emoji if score is the same
* Tue Mar 21 2017 maiku.fabian@gmail.com
- update to 1.5.29
- Add Recommends: noto-coloremoji-fonts, “Noto Color Emoji”
  looks much better than “Symbola” even in gray scale.
- Update translations from zanata (de, pl updated)
- Add a “--version” command line option to emoji-picker
- itb_emoji.py: Also read emoji-test.txt (from unicode.org)
- emoji-picker: Set default font to first available in
  ['Noto Color Emoji', 'Emoji One', 'Symbola']
- Small parsing improvement of emoji-sequences.txt
- Add support to either use U+FE0F VARIATION SELECTOR-16 in emoji sequences or not
- emoji-picker: Show “∅ Search produced empty result.” when nothing matches in a search
* Sat Mar 18 2017 maiku.fabian@gmail.com
- update to 1.5.28
- Allow query by code point even if Python’s unicodedata.name()
  does not know the character
- Also read names from emoji-sequences.txt and emoji-zwj-sequences.txt
- itb_emoji.py: Also read emoji-sequences.txt (from unicode.org)
- Fix positioning of info popover (fix a typo in an “if” statement)
- Show emoji properties from unicode.org when debugging is on
- itb_emoji.py: Also read emoji-zwj-sequences.txt (from unicode.org)
- Also use the emoji properties from unicode.org to decide whether
  to offer a lookup on emojipedia
- Use property “Emoji_Modifier_Base” from emoji-data.txt to check
  whether an emoji supports skin tones
- itb_emoji.py: Also read emoji-data.txt (from unicode.org)
- Tentative skin tone support for families
- Improve skin tone support: make it work for professions (roles) as well
- Make skin tone popover scrollable and limit its maximum size
* Fri Mar 17 2017 maiku.fabian@gmail.com
- update to 1.5.27
- Update translations from zanata (pl, uk updated)
- emoji-picker: make skin tone selection work for gendered emoji
* Thu Mar 16 2017 maiku.fabian@gmail.com
- update to 1.5.26
- Update translations from zanata (de updated)
- Emulate xdg.BaseDirectory.save_data_path() on systems which lack pyxdg
- Show the skin tone popover also on a long press gesture
- Fix pyhunspell support
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/5#issuecomment-286251818
* Tue Mar 14 2017 maiku.fabian@gmail.com
- add python3-pyxdg to BuildRequires only for
  0%%{?sle_version} >= 120200
* Mon Mar 13 2017 maiku.fabian@gmail.com
- add python3-pyxdg to BuildRequires
* Mon Mar 13 2017 maiku.fabian@gmail.com
- update to 1.5.25
- Update translations from zanata (de, pl, uk updated, zh_CN new)
- Show the categories as well on right mouse click in emoji-picker
- Improve information displayed on right mouse click in emoji-picker
- html.unescape() the strings parsed from the cldr annotations
- Fix fontsize change for invisible emoji in browse flowbox
- Add an option whether the arrow keys are allowed to reopen a preëdit
- Add an option to work around the broken forward_key_event()
  in the Qt 4/5 im module
- Use xdg.BaseDirectory to add a USER_DATADIR to the
  search path for data for itb_emoji.py
- emoji_picker.py: Speedup: Fix wrong indentation of block
  in _fill_flowbox_browse()
- emoji_picker.py: Print some profiling information when debugging is enabled
- Store the clipboard with gtk_clipboard_store() to keep it around
  after emoji-picker quits
- emoji-picker: Do not override the decoration layout of the header bar
- When an emoji with a different skin tone is selected,
  replace the original emoji immediately
- Make emoji-picker work on dark themes like Adwaita-dark as well
* Mon Mar  6 2017 maiku.fabian@gmail.com
- update to 1.5.24
- Update translations from zanata (de updated)
- The spin button to change the fontsize should grab focus without selecting
- emoji-picker: Don’t check if ibus is running,
  ibus does not need to run for emoji-picker
- Load .desktop files for emoji-picker and ibus-setup-typing-booster
  correctly under Gnome Wayland
- Show the most recently used skin tone by default
- Use Popovers for skin tones
- Don’t use HeaderBar with the default widget titlebar
- Display the detailed information of an emoji as a popover, not as a tooltip
- Use CSS to show light gray borders around flowbox and listbox children
* Mon Feb 27 2017 maiku.fabian@gmail.com
- remove fix-emoji-picker-desktop-file.patch (fixed upstream)
* Mon Feb 27 2017 maiku.fabian@gmail.com
- update to 1.5.23
- Update translations from zanata (de, ja, pl, uk updated)
- emoji_picker.py: Add a menu button to change the font for the emoji
- emoji-picker: Make background colour of the flowbox listing the emoji white
- emoji-picker: Use “Symbola” as the default font
- Remember the font and the fontsize in a config file
- emoji_picker.py: Add a spin button to change the font size of the emoji
- Add option to the emoji-picker to load *all* Unicode characters
- UI redesign of the emoji-picker
- Return an empty list immediately if candidates() is called with an empty search string
- Make the fontsize for the names of the emoji in the search results smaller
- Make the search in emoji-picker a bit more responsive by using GLib.idle_add()
- Save the recently used emoji immediately, not only when the program quits
- Set default font size of emoji-picker to 24 instead of 16
- Set the emoji font only for the emoji, not for its name in the search results
- Set WM_CLASS of emoji-picker and ibus-setup-typing-booster correctly
- Add “Icon” and “Categories” to emoji-picker.desktop
* Fri Feb 24 2017 maiku.fabian@gmail.com
- Remove "Buildarch: noarch" again
  (does not build when --libexecdir=%%{_prefix}/%%{_lib}/ibus is used
  but that probably has to be used)
* Wed Feb 22 2017 maiku.fabian@gmail.com
- make it noarch
* Wed Feb 22 2017 maiku.fabian@gmail.com
- fix build (thanks to Stefan Dirsch)
* Wed Feb 22 2017 maiku.fabian@gmail.com
- fix emoji-picker desktop file
* Wed Feb 22 2017 maiku.fabian@gmail.com
- update to 1.5.22
- Update translations from zanata (de, fr, pl, uk updated)
- Add an emoji-picker
- Update of en.xml from CLDR’s emoji annotations
- Fix skipping of the Korean test case when no Korean dictionary can be found
- Fix invalid xml in typing-booster.appdata.xml
- add Requires: python3-pyxdg (for the emoji-picker)
* Wed Feb  8 2017 maiku.fabian@gmail.com
- add BuildRequires:  python3
  This seems to contain sqlite3, needed for "make check"
* Tue Feb  7 2017 maiku.fabian@gmail.com
- update to 1.5.21
- add BuildRequires:  hunspell-fr_FR (for make check)
- Handle Return and Enter correctly when the cursor is not at
  the end of the preëdit (Resolves: rhbz#1418313)
- Values of spin buttons should not be translatable
- Make the categories from emojione translatable
- Make emoji matching accent insensitive
- If available use pykakasi to convert Japanese emoji category
  names to hiragana
- If available use the “pinyin” Python module to add pinyin
  to the Chinese names and keywords
- Don’t fallback to “zh” from “zh_TW”, “zh_HK”, “zh_MO” and “zh_Hant”
- Don’t sort the labels when listing similar emoji
- Don’t change Unicode categories to lowercase when loading,
  use the original case
- Also treat categories 'Zl' and 'Zp' as invisible and add
  Unicode code point
- When searching for similar emoji, the original emoji should be
  most similar to itself
- Fix duplicate listing of labels when looking up similar emoji
- Make it optionally possible to match emoji in Japanese using romaji
- itb_emoji.py: Add the code point to the name of invisible
  characters also when looking up similar characters
- Better matching of the Unicode categories
- Small performance optimization in EmojiMatcher.similar()
- Remove any U+2028 LINE SEPARATOR and U+2029 PARAGRAPH SEPARATOR characters
  from the lookup table
- Nicer display of the matching labels when looking up similar emoji
- Don’t strip mathematical symbols (category 'Sm') from tokens
- Update of en.xml from CLDR’s emoji annotations
- Update translations from zanata (de, pl updated)
* Fri Jan 27 2017 maiku.fabian@gmail.com
- update to 1.5.20
- Calculate the maximum word length for each dictionary individually
- Use .startswith instead of regexp matching when matching in hunspell
  dictionaries (speed optimization)
- Improve accent insensitive matching (“filosofičtějš” should also
  match “filosofičtější”)
- Some updates for the emoji annotations in en.xml from CLDR
* Thu Jan 19 2017 maiku.fabian@gmail.com
- update to 1.5.19
- Improve setup layout (thanks to Trinh Anh Ngoc <atw1990@gmail.com>)
- Add some more directories to search for dictionaries (for FreeBSD)
- Wrong variable “page_size” was used in set_lookup_table_orientation()
- Do not try to reopen the preëdit when any modifier except
  CapsLock is on (Resolves: rhbz#1414642)
* Tue Jan 17 2017 maiku.fabian@gmail.com
- update to 1.5.18
- Fix typo in the “Unbreak sqlite on Python 3.6” patch
- Fix the fallback to use pyhunspell-python3 when python3-enchant
  is not available
- Remove useless ibus-typing-booster.pc
* Fri Jan 13 2017 maiku.fabian@gmail.com
- update to 1.5.17
- Update py-compile to current upstream version
- Also use ＿ U+FF3F FULLWIDTH LOW LINE as a separator for emoji keywords
- Unbreak sqlite on Python 3.6 (thanks to Jan Alexander Steffens)
- Return immediately if _update_candidates() is called with
  empty input (Resolves: rhbz#1413082)
* Tue Jan 10 2017 maiku.fabian@gmail.com
- update  to 1.5.16
- Remove everything following a tab (including the tab) from
  hunspell dictionary lines (Resolves: rhbz#1411659)
- Delete a candidate correctly from the user database even if
  it starts with a prefix to be stripped from tokens (Resolves: rhbz#1411676)
- Trigger emoji lookup when the input starts or ends with '_' or ' '
- Better handling of BackSpace and Delete when reaching the
  ends of the preëdit (Resolves: rhbz#1411688)
- Search for hunspell dictionaries in a list of directories
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/6)
* Thu Dec  8 2016 maiku.fabian@gmail.com
- first version for SuSE 1.5.15
